@@ -1,12 +1,12 @@
 import json
 import logging
-import textwrap
+
+from elasticsearch.exceptions import NotFoundError
+from pyhocon import ConfigTree  # noqa: F401
 from typing import List  # noqa: F401
 
-from pyhocon import ConfigTree  # noqa: F401
-from elasticsearch.exceptions import NotFoundError
-
 from databuilder.publisher.base_publisher import Publisher
+from databuilder.publisher.elasticsearch_constants import TABLE_ELASTICSEARCH_INDEX_MAPPING
 
 LOGGER = logging.getLogger(__name__)
 
@@ -32,95 +32,7 @@ class ElasticsearchPublisher(Publisher):
     # config to control how many max documents to publish at a time
     ELASTICSEARCH_PUBLISHER_BATCH_SIZE = 'batch_size'
 
-    # Specifying default mapping for elasticsearch index
-    # Documentation: https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping.html
-    # Setting type to "text" for all fields that would be used in search
-    # Using Simple Analyzer to convert all text into search terms
-    # https://www.elastic.co/guide/en/elasticsearch/reference/current/analysis-simple-analyzer.html
-    # Standard Analyzer is used for all text fields that don't explicitly specify an analyzer
-    # https://www.elastic.co/guide/en/elasticsearch/reference/current/analysis-standard-analyzer.html
-    # TODO use amundsencommon for this when this project is updated to py3
-    DEFAULT_ELASTICSEARCH_INDEX_MAPPING = textwrap.dedent(
-        """
-        {
-        "mappings":{
-            "table":{
-              "properties": {
-                "name": {
-                  "type":"text",
-                  "analyzer": "simple",
-                  "fields": {
-                    "raw": {
-                      "type": "keyword"
-                    }
-                  }
-                },
-                "schema": {
-                  "type":"text",
-                  "analyzer": "simple",
-                  "fields": {
-                    "raw": {
-                      "type": "keyword"
-                    }
-                  }
-                },
-                "display_name": {
-                  "type": "keyword"
-                },
-                "last_updated_timestamp": {
-                  "type": "date",
-                  "format": "epoch_second"
-                },
-                "description": {
-                  "type": "text",
-                  "analyzer": "simple"
-                },
-                "column_names": {
-                  "type":"text",
-                  "analyzer": "simple",
-                  "fields": {
-                    "raw": {
-                      "type": "keyword"
-                    }
-                  }
-                },
-                "column_descriptions": {
-                  "type": "text",
-                  "analyzer": "simple"
-                },
-                "tags": {
-                  "type": "keyword"
-                },
-                "badges": {
-                  "type": "keyword"
-                },
-                "cluster": {
-                  "type": "text"
-                },
-                "database": {
-                  "type": "text",
-                  "analyzer": "simple",
-                  "fields": {
-                    "raw": {
-                      "type": "keyword"
-                    }
-                  }
-                },
-                "key": {
-                  "type": "keyword"
-                },
-                "total_usage":{
-                  "type": "long"
-                },
-                "unique_usage": {
-                  "type": "long"
-                }
-              }
-            }
-          }
-        }
-        """
-    )
+    DEFAULT_ELASTICSEARCH_INDEX_MAPPING = TABLE_ELASTICSEARCH_INDEX_MAPPING
 
     def __init__(self):
         # type: () -> None
